@@ -1,13 +1,11 @@
 import requests
 import re
 import os
-import websocket
 import json
 import time
 import logging
 import sys
 import json
-import ScratchEncoder
 import os
 try:
     ws = websocket.WebSocket()
@@ -370,8 +368,9 @@ class Scratch2Py():
             return titles
 
     class cloud:
-        def __init__(self, pid):
+        def __init__(self, username, pid):
             PROJECT_ID = pid
+            self.username = username
         def setCloudVar(self, variable, value):
             try:
                 ws.send(json.dumps({
